@@ -7,5 +7,8 @@ import os
 from tempor import ROOT_DIR
 from tempor.console import console
 
-def run_playbook(playbook='main.yml'):
-    ansible_runner.run(private_data_dir=f'{ROOT_DIR}/playbooks', playbook=playbook, verbosity=1)
+
+def run_playbook(playbook="main.yml"):
+    ansible_runner.run(
+        private_data_dir=f"{ROOT_DIR}/playbooks", playbook=playbook, verbosity=1
+    )
